/*
 * The MIT License (MIT)
 *
 * Copyright (C) 2019, CosmicMind, Inc. <http://cosmicmind.com>.
 * All rights reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

import UIKit

class IgnoreSubviewTransitionsPreprocessor: MotionCorePreprocessor {
  /**
   Processes the transitionary views.
   - Parameter fromViews: An Array of UIViews.
   - Parameter toViews: An Array of UIViews.
   */
  override func process(fromViews: [UIView], toViews: [UIView]) {
    process(views: fromViews)
    process(views: toViews)
  }
  
  /**
   Process an Array of views for the cascade animation.
   - Parameter views: An Array of UIViews.
   */
  func process(views: [UIView]) {
    for v in views {
      guard let recursive = context[v]?.ignoreSubviewTransitions else {
        continue
      }
      
      var parentView = v
      
      if v is UITableView, let wrapperView = v.subviews.get(0) {
        parentView = wrapperView
      }
      
      guard recursive else {
        for subview in parentView.subviews {
          context[subview] = nil
        }
        
        continue
      }
      
      cleanSubviewModifiers(for: parentView)
    }
  }
}

fileprivate extension IgnoreSubviewTransitionsPreprocessor {
  /**
   Clears the modifiers for a given view's subviews.
   - Parameter for view: A UIView.
   */
  func cleanSubviewModifiers(for view: UIView) {
    for v in view.subviews {
      context[v] = nil
      cleanSubviewModifiers(for: v)
    }
  }
}
